## Summary

<!-- Brief description of what this PR does -->

## Changes

<!-- List the main changes -->

-

## Checklist

- [ ] Tests added/updated
- [ ] Documentation updated (if applicable)
- [ ] CHANGELOG.md updated (for user-facing changes)
- [ ] All tests pass (`uv run pytest`)
- [ ] Linting passes (`uv run ruff check .`)
- [ ] Type checking passes (`uv run mypy src`)

## Related Issues

<!-- Link any related issues: Fixes #123, Closes #456 -->
